import { ChevronRight, User } from "lucide-react";

import {
	Accordion,
	AccordionContent,
	AccordionItem,
	AccordionTrigger,
} from "@/components/ui/accordion";
import {
	Sheet,
	SheetContent,
	SheetDescription,
	SheetTitle,
	SheetTrigger,
} from "@/components/ui/sheet";
import { Link } from "@/i18n/routing";

const navItems = [
	{ href: "/", label: "الرئيسية", active: true },
	{ href: "/", label: "تاريخنا" },
	{
		href: "/",
		label: "خدماتنا",
		hasDropdown: true,
		dropdownItems: [
			{ href: "/", label: "خدمة 1" },
			{ href: "/", label: "خدمة 2" },
			{ href: "/", label: "خدمة 3" },
		],
	},
	{ href: "/", label: "مشاريعنا" },
	{ href: "/", label: "منتجات" },
	{ href: "/", label: "المكتبة" },
];

export default function MobileNavigation() {
	return (
		<Sheet>
			<SheetTrigger asChild>
				<button className="p-2 lg:hidden" aria-label="Open menu">
					<svg
						width="24"
						height="24"
						viewBox="0 0 15 15"
						fill="none"
						xmlns="http://www.w3.org/2000/svg"
					>
						<path
							d="M1.5 3C1.22386 3 1 3.22386 1 3.5C1 3.77614 1.22386 4 1.5 4H13.5C13.7761 4 14 3.77614 14 3.5C14 3.22386 13.7761 3 13.5 3H1.5ZM1 7.5C1 7.22386 1.22386 7 1.5 7H13.5C13.7761 7 14 7.22386 14 7.5C14 7.77614 13.7761 8 13.5 8H1.5C1.22386 8 1 7.77614 1 7.5ZM1 11.5C1 11.2239 1.22386 11 1.5 11H13.5C13.7761 11 14 11.2239 14 11.5C14 11.7761 13.7761 12 13.5 12H1.5C1.22386 12 1 11.7761 1 11.5Z"
							fill="currentColor"
							fillRule="evenodd"
							clipRule="evenodd"
						></path>
					</svg>
				</button>
			</SheetTrigger>
			<SheetContent
				side="right"
				className="w-full max-w-[300px] overflow-y-auto bg-custom-primary p-0 text-white sm:w-[400px]"
			>
				<SheetTitle className="sr-only">Navigation Menu</SheetTitle>
				<SheetDescription className="sr-only">
					Access navigation options and user account
				</SheetDescription>
				<div className="flex h-full flex-col">
					<div className="bg-custom-secondary p-6">
						<Link
							href="/"
							className="flex items-center gap-2 text-white transition-colors hover:text-custom-tertiary"
						>
							<User className="size-6" />
							<span className="text-lg font-semibold">
								تسجيل دخول / تسجيل حساب
							</span>
						</Link>
					</div>
					<nav className="flex-1 p-6">
						<ul className="space-y-6">
							{navItems?.map((item) => (
								<li key={item.href}>
									{item.hasDropdown ? (
										<Accordion
											type="single"
											collapsible
											className="border-b border-custom-tertiary/20"
										>
											<AccordionItem value={item.href} className="border-none">
												<AccordionTrigger className="py-2 text-lg transition-colors hover:text-custom-tertiary">
													{item.label}
												</AccordionTrigger>
												<AccordionContent>
													<ul className="mt-2 space-y-2">
														{item.dropdownItems?.map((dropdownItem) => (
															<li key={dropdownItem.href}>
																<Link
																	href={"/"}
																	className="block py-2 pr-4 transition-colors hover:text-custom-tertiary"
																>
																	{dropdownItem.label}
																</Link>
															</li>
														))}
													</ul>
												</AccordionContent>
											</AccordionItem>
										</Accordion>
									) : (
										<Link
											href={"/"}
											className={`flex items-center justify-between py-2 transition-colors hover:text-custom-tertiary ${item.active ? "font-bold" : ""
												}`}
										>
											{item.label}
											<ChevronRight className="size-5" />
										</Link>
									)}
								</li>
							))}
						</ul>
					</nav>
				</div>
			</SheetContent>
		</Sheet>
	);
}
